@@ -1,14 +1,9 @@
 #' @rdname export
 #' @export
 export.sc_power <- function(object, caption = NA, footnote = NA, filename = NA,
-                            kable_styling_options = list(), 
-                            kable_options = list(), 
                             round = 3,
                             ...) {
   
-  kable_options <- .join_kabel(kable_options)
-  kable_styling_options <- .join_kabel_styling(kable_styling_options)
-  
   if (is.na(caption)) {
     caption <- c("Test power in percent")
   }
@@ -23,8 +18,6 @@ export.sc_power <- function(object, caption = NA, footnote = NA, filename = NA,
   
   table <- .create_table(
     out, 
-    kable_options, 
-    kable_styling_options, 
     caption = caption,
     footnote = footnote,
     ...
