@@ -17,10 +17,11 @@
     scan.print.cols   = "all",
     scan.print.digits = 2,
     scan.print.long   = FALSE,
-    scan.print.bar   = "|",
+    scan.print.bar   = "\u2502", #"|",
     scan.print.scdf.name = TRUE,
     scan.plot.style = "grid",
     scan.rename.predictors = "full",
+    scan.rsquared = "delta",
     scan.string.dummy.slope = "inter",
     scan.string.dummy.phase = "phase",
     scan.deprecated.warning = TRUE,
